@@ -1,8 +1,12 @@
 import dask.array as da
+import metpy.calc as mpcalc
 import numpy as np
+import pint.quantity
 import typing
-import xarray as xr
 import warnings
+import xarray as xr
+from itertools import chain
+from metpy.units import units
 
 
 def _dewtemp(
@@ -20,7 +24,7 @@ def _dewtemp(
         Temperature in Kelvin
 
     rh : ndarray, :class:`xarray.DataArray`, :obj:`list`, or :obj:`float`
-        Relative humidity. Must be the same dimensions as temperature
+        Relative humidity. Must be the same dimensions as ``temperature``
 
     Returns
     -------
@@ -61,7 +65,7 @@ def _heat_index(temperature: np.ndarray,
 
     relative_humidity : ndarray, :class:`xarray.DataArray`, :class:`list`, :class:`float`
         relative humidity as a percentage. Must be the same shape as
-        temperature
+        ``temperature``
 
     alternate_coeffs : bool, optional
         flag to use alternate set of coefficients appropriate for
@@ -70,7 +74,7 @@ def _heat_index(temperature: np.ndarray,
     Returns
     -------
     heatindex : ndarray
-        Calculated heat index. Same shape as temperature
+        Calculated heat index. Same shape as ``temperature``
 
 
     See Also
@@ -147,12 +151,12 @@ def _nws_eqn(coeffs, temp, rel_hum):
 
     rel_hum : ndarray, :class:`xarray.DataArray`, :class:`list`, :class:`float`
         relative humidity as a percentage. Must be the same shape as
-        temperature
+        ``temperature``
 
     Returns
     -------
     heatindex : ndarray, :class:`xarray.DataArray`, :class:`list`, :class:`float`
-        Intermediate calculated heat index. Same shape as temperature
+        Intermediate calculated heat index. Same shape as ``temperature``
 
 
     See Also
@@ -196,15 +200,15 @@ def _relhum(
         Temperature in Kelvin
 
     w : ndarray, :class:`xarray.DataArray`, :obj:`list`, or :obj:`float`
-        Mixing ratio in kg/kg. Must have the same dimensions as temperature
+        Mixing ratio in kg/kg. Must have the same dimensions as ``temperature``
 
     p : ndarray, :class:`xarray.DataArray`, :obj:`list`, or :obj:`float`
-        Pressure in Pa. Must have the same dimensions as temperature
+        Pressure in Pa. Must have the same dimensions as ``temperature``
 
     Returns
     -------
     rh : ndarray
-        Relative humidity. Will have the same dimensions as temperature
+        Relative humidity. Will have the same dimensions as ``temperature``
 
 
     See Also
@@ -276,10 +280,10 @@ def _relhum_ice(t: typing.Union[np.ndarray, list, float],
     """Calculates relative humidity with respect to ice, given temperature,
     mixing ratio, and pressure.
 
-     "Improved Magnus' Form Approx. of Saturation Vapor pressure"
-     Oleg A. Alduchov and Robert E. Eskridge
-     http://www.osti.gov/scitech/servlets/purl/548871/
-     https://doi.org/10.2172/548871
+    "Improved Magnus' Form Approx. of Saturation Vapor pressure"
+    Oleg A. Alduchov and Robert E. Eskridge
+    http://www.osti.gov/scitech/servlets/purl/548871/
+    https://doi.org/10.2172/548871
 
     Parameters
     ----------
@@ -287,15 +291,15 @@ def _relhum_ice(t: typing.Union[np.ndarray, list, float],
         Temperature in Kelvin
 
     w : ndarray, :obj:`list`, :obj:`float`
-        Mixing ratio in kg/kg. Must have the same dimensions as temperature
+        Mixing ratio in kg/kg. Must have the same dimensions as ``temperature``
 
     p : ndarray, :obj:`list`, :obj:`float`
-        Pressure in Pa. Must have the same dimensions as temperature
+        Pressure in Pa. Must have the same dimensions as ``temperature``
 
     Returns
     -------
     rh : ndarray
-        Relative humidity. Will have the same dimensions as temperature
+        Relative humidity. Will have the same dimensions as ``temperature``
 
 
     See Also
@@ -336,14 +340,15 @@ def _relhum_water(t: typing.Union[np.ndarray, list, float],
     """Calculates relative humidity with respect to water, given temperature,
     mixing ratio, and pressure.
 
-    Definition of mixing ratio if,
+    Definition of mixing ratio if:
 
-    - es  - is the saturation mixing ratio
-    - ep  - is the ratio of the molecular weights of water vapor to dry air
-    - p   - is the atmospheric pressure
-    - rh  - is the relative humidity (given as a percent)
+    - ``es``  - is the saturation mixing ratio
+    - ``ep``  - is the ratio of the molecular weights of water vapor to dry air
+    - ``p``   - is the atmospheric pressure
+    - ``rh``  - is the relative humidity (given as a percent)
 
-    rh =  100*  q / ( (ep*es)/(p-es) )
+    .. math::
+        rh =  100*  q / ( (ep*es)/(p-es) )
 
     Parameters
     ----------
@@ -351,15 +356,15 @@ def _relhum_water(t: typing.Union[np.ndarray, list, float],
         Temperature in Kelvin
 
     w : ndarray, :obj:`list`, :obj:`float`
-        Mixing ratio in kg/kg. Must have the same dimensions as temperature
+        Mixing ratio in kg/kg. Must have the same dimensions as ``temperature``
 
     p : ndarray, :obj:`list`, :obj:`float`
-        Pressure in Pa. Must have the same dimensions as temperature
+        Pressure in Pa. Must have the same dimensions as ``temperature``
 
     Returns
     -------
     rh : ndarray
-        Relative humidity. Will have the same dimensions as temperature
+        Relative humidity. Will have the same dimensions as ``temperature``
 
     See Also
     --------
@@ -407,7 +412,7 @@ def _xheat_index(temperature: xr.DataArray,
 
     relative_humidity : :class:`xarray.DataArray`
         relative humidity as a percentage. Must be the same shape as
-        temperature
+        ``temperature``
 
     alternate_coeffs : bool, optional
         flag to use alternate set of coefficients appropriate for
@@ -416,7 +421,7 @@ def _xheat_index(temperature: xr.DataArray,
     Returns
     -------
     heatindex : :class:`xarray.DataArray`
-        Calculated heat index. Same shape as temperature
+        Calculated heat index. Same shape as ``temperature``
 
     eqtype : :class:`int`
         version of equations used, for xarray attrs output
@@ -495,15 +500,15 @@ def _xrelhum(t: xr.DataArray, w: xr.DataArray, p: xr.DataArray) -> xr.DataArray:
         Temperature in Kelvin
 
     w : :class:`xarray.DataArray`
-        Mixing ratio in kg/kg. Must have the same dimensions as temperature
+        Mixing ratio in kg/kg. Must have the same dimensions as ``temperature``
 
     p : :class:`xarray.DataArray`
-        Pressure in Pa. Must have the same dimensions as temperature
+        Pressure in Pa. Must have the same dimensions as ``temperature``
 
     Returns
     -------
     rh : :class:`xarray.DataArray`
-        Relative humidity. Will have the same dimensions as temperature
+        Relative humidity. Will have the same dimensions as ``temperature``
 
 
     See Also
@@ -584,7 +589,7 @@ def dewtemp(
         Temperature in Kelvin
 
     relative_humidity : ndarray, :class:`xarray.DataArray`, :obj:`list`, or :obj:`float`
-        Relative humidity. Must be the same dimensions as temperature
+        Relative humidity. Must be the same dimensions as ``temperature``
 
     Returns
     -------
@@ -645,9 +650,9 @@ def heat_index(
     The heat index calculation in this funtion is described at:
     https://www.wpc.ncep.noaa.gov/html/heatindex_equation.shtml
 
-    The 'Heat Index' is a measure of how hot weather "feels" to the body. The combination of temperature an humidity
+    The 'Heat Index' is a measure of how hot weather "feels" to the body. The combination of temperature and humidity
     produce an "apparent temperature" or the temperature the body "feels". The returned values are for shady
-    locations only. Exposure to full sunshine can increase heat index values by up to 15Â°F. Also, strong winds,
+    locations only. Exposure to full sunshine can increase heat index values by up to 15°F. Also, strong winds,
     particularly with very hot, dry air, can be extremely hazardous as the wind adds heat to the body
 
     The computation of the heat index is a refinement of a result obtained by multiple regression analysis carried
@@ -656,7 +661,7 @@ def heat_index(
 
     In practice, the Steadman formula is computed first and the result averaged with the temperature. If this heat
     index value is 80 degrees F or higher, the full regression equation along with any adjustment as described above
-    is applied. If the ambient temperature is less the 40F (4.4C/277.65K), the heat index is set to to the ambient
+    is applied. If the ambient temperature is less the 40F (4.4C/277.65K), the heat index is set to the ambient
     temperature.
 
     Parameters
@@ -666,7 +671,7 @@ def heat_index(
 
     relative_humidity : ndarray, :class:`xarray.DataArray`, :class:`list`, :class:`float`
         relative humidity as a percentage. Must be the same shape as
-        temperature
+        ``temperature``
 
     alternate_coeffs : bool, optional
         flag to use alternate set of coefficients appropriate for
@@ -675,7 +680,7 @@ def heat_index(
     Returns
     -------
     heatindex : ndarray, :class:`xarray.DataArray`
-        Calculated heat index. Same shape as temperature
+        Calculated heat index. Same shape as ``temperature``
 
     Examples
     --------
@@ -783,15 +788,15 @@ def relhum(
         Temperature in Kelvin
 
     mixing_ratio : ndarray, :class:`xarray.DataArray`, :obj:`list`, or :obj:`float`
-        Mixing ratio in kg/kg. Must have the same dimensions as temperature
+        Mixing ratio in kg/kg. Must have the same dimensions as ``temperature``
 
     pressure : ndarray, :class:`xarray.DataArray`, :obj:`list`, or :obj:`float`
-        Pressure in Pa. Must have the same dimensions as temperature
+        Pressure in Pa. Must have the same dimensions as ``temperature``
 
     Returns
     -------
     relative_humidity : ndarray or :class:`xarray.DataArray`
-        Relative humidity. Will have the same dimensions as temperature
+        Relative humidity. Will have the same dimensions as ``temperature``
 
 
     See Also
@@ -851,10 +856,10 @@ def relhum_ice(temperature: typing.Union[np.ndarray, list, float],
     """Calculates relative humidity with respect to ice, given temperature,
     mixing ratio, and pressure.
 
-     "Improved Magnus' Form Approx. of Saturation Vapor pressure"
-     Oleg A. Alduchov and Robert E. Eskridge
-     http://www.osti.gov/scitech/servlets/purl/548871/
-     https://doi.org/10.2172/548871
+    "Improved Magnus' Form Approx. of Saturation Vapor pressure"
+    Oleg A. Alduchov and Robert E. Eskridge
+    http://www.osti.gov/scitech/servlets/purl/548871/
+    https://doi.org/10.2172/548871
 
     Parameters
     ----------
@@ -862,15 +867,15 @@ def relhum_ice(temperature: typing.Union[np.ndarray, list, float],
         Temperature in Kelvin
 
     mixing_ratio : ndarray, :obj:`list`, or :obj:`float`
-        Mixing ratio in kg/kg. Must have the same dimensions as temperature
+        Mixing ratio in kg/kg. Must have the same dimensions as ``temperature``
 
     pressure : ndarray, :obj:`list`, or :obj:`float`
-        Pressure in Pa. Must have the same dimensions as temperature
+        Pressure in Pa. Must have the same dimensions as ``temperature``
 
     Returns
     -------
     relative_humidity : ndarray
-        Relative humidity. Will have the same dimensions as temperature
+        Relative humidity. Will have the same dimensions as ``temperature``
 
     See Also
     --------
@@ -923,13 +928,15 @@ def relhum_water(temperature: typing.Union[np.ndarray, list, float],
     """Calculates relative humidity with respect to water, given temperature,
     mixing ratio, and pressure.
 
-    Definition of mixing ratio if,
-    es  - is the saturation mixing ratio
-    ep  - is the ratio of the molecular weights of water vapor to dry air
-    p   - is the atmospheric pressure
-    rh  - is the relative humidity (given as a percent)
+    Definition of mixing ratio if:
 
-    rh =  100*  q / ( (ep*es)/(p-es) )
+    - `es`  - is the saturation mixing ratio
+    - `ep`  - is the ratio of the molecular weights of water vapor to dry air
+    - `p`   - is the atmospheric pressure
+    - `rh`  - is the relative humidity (given as a percent)
+
+    .. math::
+        rh =  100  q / ( (ep*es)/(p-es) )
 
     Parameters
     ----------
@@ -937,15 +944,15 @@ def relhum_water(temperature: typing.Union[np.ndarray, list, float],
         Temperature in Kelvin
 
     mixing_ratio : ndarray, :obj:`list`, or :obj:`float`
-        Mixing ratio in kg/kg. Must have the same dimensions as temperature
+        Mixing ratio in kg/kg. Must have the same dimensions as ``temperature``
 
     pressure : ndarray, :obj:`list`, or :obj:`float`
-        Pressure in Pa. Must have the same dimensions as temperature
+        Pressure in Pa. Must have the same dimensions as ``temperature``
 
     Returns
     -------
     relative_humidity : ndarray
-        Relative humidity. Will have the same dimensions as temperature
+        Relative humidity. Will have the same dimensions as ``temperature``
 
     See Also
     --------
@@ -990,3 +997,419 @@ def relhum_water(temperature: typing.Union[np.ndarray, list, float],
                                          attrs=save_attrs)
 
     return relative_humidity
+
+
+def showalter_index(pressure: pint.Quantity, temperature: pint.Quantity,
+                    dewpt: pint.Quantity) -> pint.Quantity:
+    """Calculate Showalter Index from pressure temperature and 850 hPa lcl.
+    Showalter Index derived from `Gallway 1956 <https://journals.ametsoc.org/do
+    wnloadpdf/journals/bams/37/10/1520-0477-37_10_528.xml>`__.
+
+    :math:`shox = T500 - Tp500`
+
+    - `T500` is the measured temperature at 500 hPa
+    - `Tp500` is the temperature of the lifted parcel at 500 hPa
+
+    Parameters
+    ----------
+    pressure : :class:`pint.Quantity`
+        Atmospheric pressure level(s) of interest, in order from highest
+        to lowest pressure
+    temperature : :class:`pint.Quantity`
+        Parcel temperature for corresponding pressure
+    dewpt : :class:`pint.Quantity`
+        Parcel dew point temperatures for corresponding pressure
+
+    Returns
+    -------
+    shox : :class:`pint.Quantity`
+       Showalter index in delta degrees celsius
+    """
+    shox = mpcalc.showalter_index(pressure, temperature, dewpt)
+    return shox
+
+
+def max_daylight(
+    jday: typing.Union[np.ndarray, xr.DataArray, list,
+                       float], lat: typing.Union[np.ndarray, xr.DataArray, list,
+                                                 float]
+) -> typing.Union[np.ndarray, xr.DataArray, float]:
+    """Computes maximum number of daylight hours as described in the Food and
+    Agriculture Organization (FAO) Irrigation and Drainage Paper 56 entitled:
+
+    Crop evapotranspiration - Guidelines for computing crop water
+    requirement. Specifically, see equation 34 of Chapter 3.
+
+    Note for abs(lat) > 55 the eqns have limited validity.
+
+    Parameters
+    ----------
+    jday : ndarray, :class:`xarray.DataArray`, :class:`list`, :class:`float`
+        Day of year. Must be 1D
+
+    lat : ndarray, :class:`xarray.DataArray`, :class:`list`, :class:`float`
+        Latitude in degrees. Must be 1D
+
+    Returns
+    -------
+    sunmax : ndarray, :class:`xarray.DataArray`, :class:`float`
+        Calculated maximum sunlight in hours/day
+
+    Examples
+    --------
+    >>> from geocat.comp import max_daylight
+    >>> import numpy as np
+    >>> jday = np.array([100, 123, 246])
+    >>> lat = np.array([10, 20])
+    >>> max_daylight(jday, lat)
+    array([[12.18035083, 12.37238906],
+           [12.37577081, 12.77668231],
+           [12.16196585, 12.33440805]])
+
+
+    See Also
+    --------
+    Related NCL Functions:
+    `daylight_fao56 <https://www.ncl.ucar.edu/Document/Functions/Crop/daylight_fao56.shtml>`__
+    """
+
+    x_out = False
+    if isinstance(jday, xr.DataArray):
+        x_out = True
+
+    # convert inputs to numpy arrays for function call if necessary
+    if not xr.core.utils.is_duck_array(jday):
+        jday = np.asarray(jday, dtype='float32')
+    if not xr.core.utils.is_duck_array(lat):
+        lat = np.asarray(lat, dtype='float32')
+
+    # check to ensure dimension of lat is not greater than two
+    if lat.ndim > 1 or jday.ndim > 1:
+        raise ValueError('max_daylight: inputs must have at most one dimension')
+
+    # check if latitude is outside of acceptable ranges
+    # warn if more than abs(55)
+    # Give stronger warning if more than abs(66)
+    if (abs(lat) > 55).all() and (abs(lat) <= 66).all():
+        warnings.warn(
+            "WARNING: max_daylight has limited validity for abs(lat) > 55 ")
+    elif (abs(lat) > 66).all():
+        warnings.warn(
+            'WARNING: max_daylight: calculation not possible for abs(lat) > 66 for all values of jday, '
+            'errors may occur')
+
+    # define constants
+    pi = np.pi
+    rad = pi / 180
+    pi2yr = 2 * pi / 365
+    latrad = lat * rad
+    con = 24 / pi
+
+    # Equation 24 from FAO56
+    sdec = 0.409 * np.sin(pi2yr * jday - 1.39)
+
+    # Equation 25 from FAO56
+    ws = np.arccos(np.outer(-np.tan(latrad), np.tan(sdec)))
+
+    # Equation 34 from FAO56
+    dlm = np.transpose(con * ws)
+
+    # handle metadata if xarray output
+    if x_out:
+        dlm = xr.DataArray(dlm, coords=[jday, lat], dims=["doy", "lat"])
+        dlm.attrs['long_name'] = "maximum daylight: FAO_56"
+        dlm.attrs['units'] = "hours/day"
+        dlm.attrs['url'] = "http://www.fao.org/docrep/X0490E/x0490e07.htm"
+        dlm.attrs['info'] = "FAO 56; EQN 34; max_daylight"
+
+    return dlm
+
+
+def psychrometric_constant(
+    pressure: typing.Union[np.ndarray, xr.DataArray, list, float]
+) -> typing.Union[np.ndarray, xr.DataArray]:
+    """Compute psychrometric constant [kPa / C] as described in the Food and
+    Agriculture Organization (FAO) Irrigation and Drainage Paper 56 entitled:
+
+    Crop evapotranspiration - Guidelines for computing crop water
+    requirement. Specifically, see equation 7 of Chapter 3 or equation 3-2 in
+    Annex 3.
+
+    From FAO 56:
+
+    The specific heat at constant pressure is the amount of energy required to
+    increase the temperature of a unit mass of air by one degree at constant
+    pressure. Its value depends on the composition of the air, i.e.,  on its
+    humidity. For average atmospheric conditions a value
+    cp = 1.013 10-3 MJ kg-1 C-1 can be used. As an average atmospheric
+    pressure is used for each location (Equation 7), the psychrometric
+    constant is kept constant for each location.
+
+    A table listing the psychrometric constant for different altitudes is
+    located here: https://www.fao.org/3/X0490E/x0490e0j.htm
+
+    Parameters
+    ----------
+    pressure : ndarray, :class:`xarray.DataArray`, :class:`list`, :class:`float`
+        pressure in kPa/C
+
+    Returns
+    -------
+    psy_const : ndarray, :class:`xarray.DataArray`
+        the computed psychrometric constant. Same shape as pressure.
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> from geocat.comp import psychrometric_constant
+    >>> pressure = np.array([60, 80, 100])
+    >>> psychrometric_constant(pressure)
+    array([0.0398844, 0.0531792, 0.066474 ])
+
+
+    See Also
+    --------
+    Related NCL Functions:
+    `psychro_fao56 <https://www.ncl.ucar.edu/Document/Functions/Crop/psychro_fao56.shtml>`__
+    """
+
+    # Constant
+    con = 0.66474e-3
+
+    in_type = type(pressure)
+
+    # Psychrometric constant calculation
+    # if input not xarray, make sure in numpy for calculation
+    if in_type is not xr.DataArray:
+        psy_const = con * np.asarray(pressure)
+
+    # else if input is xarray, add relevant metadata for xarray output
+    else:
+        psy_const = con * pressure
+        psy_const.attrs['long_name'] = "psychrometric constant"
+        psy_const.attrs['units'] = "kPa/C"
+        psy_const.attrs[
+            'url'] = "https://www.fao.org/docrep/X0490E/x0490e07.htm"
+        psy_const.attrs['info'] = "FAO 56; EQN 8; psychrometric_constant"
+
+    return psy_const
+
+
+def saturation_vapor_pressure(
+    temperature: typing.Union[np.ndarray, xr.DataArray, list, float],
+    tfill: typing.Union[float] = np.nan
+) -> typing.Union[np.ndarray, xr.DataArray]:
+    """Compute saturation vapor pressure as described in the Food and
+    Agriculture Organization (FAO) Irrigation and Drainage Paper 56
+    entitled:
+
+    Crop evapotranspiration - Guidelines for computing crop water
+    requirement. Specifically, see equation 11 of Chapter 3.
+
+    This is Tetens' Formula: an empirical expression for saturation vapor
+    pressure with respect to liquid water that includes the variation of
+    latent heat with temperature.
+
+    Note that if temperature = tdew, then this function computes actual vapor
+    pressure.
+
+    Parameters
+    ----------
+    temperature : ndarray, :class:`xarray.DataArray`, :class:`list`, :class:`float`
+        Temperature in Fahrenheit
+
+    tfill : float, numpy.nan, optional
+        An optional parameter for a fill value in the return value
+
+    Returns
+    -------
+    svp : ndarray, :class:`xarray.DataArray`
+        the computed actual saturation vapor pressure in kPa.
+        Same shape as temperature.
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> from geocat.comp import saturation_vapor_pressure
+    >>> temp = np.array([50, 60, 70])
+    >>> saturation_vapor_pressure(temp)
+    array([1.22796262, 1.76730647, 2.50402976])
+
+
+    See Also
+    --------
+    Related GeoCAT Functions:
+    `actual_saturation_vapor_pressure <https://geocat-comp.readthedocs.io/en/latest/user_api/generated/geocat.comp.crop.actual_saturation_vapor_pressure.html#geocat.comp.crop.actual_saturation_vapor_pressure>`__,
+    `saturation_vapor_pressure_slope <https://geocat-comp.readthedocs.io/en/latest/user_api/generated/geocat.comp.crop.saturation_vapor_pressure_slope.html#geocat.comp.crop.saturation_vapor_pressure_slope>`__
+
+    Related NCL Functions:
+    `satvpr_temp_fao56 <https://www.ncl.ucar.edu/Document/Functions/Crop/satvpr_temp_fao56.shtml>`__
+    """
+
+    in_type = type(temperature)
+
+    if in_type is xr.DataArray:
+
+        # convert temperature to Celsius
+        temp_c = (temperature - 32) * 5 / 9
+
+        # calculate svp
+        svp = xr.where(temp_c > 0, 0.6108 * np.exp(
+            (17.27 * temp_c) / (temp_c + 237.3)), tfill)
+
+        # add relevant metadata
+        svp.attrs['long_name'] = "saturation vapor pressure"
+        svp.attrs['units'] = "kPa"
+        svp.attrs['url'] = "https://www.fao.org/docrep/X0490E/x0490e07.htm"
+        svp.attrs['info'] = "FAO 56; EQN 11; saturation_vapor_pressure"
+
+    else:
+        temperature = np.asarray(temperature)
+
+        temp_c = (temperature - 32) * 5 / 9
+        svp = np.where(temp_c > 0, 0.6108 * np.exp(
+            (17.27 * temp_c) / (temp_c + 237.3)), tfill)
+
+    return svp
+
+
+def actual_saturation_vapor_pressure(
+    tdew: typing.Union[np.ndarray, xr.DataArray, list, float],
+    tfill: typing.Union[float] = np.nan
+) -> typing.Union[np.ndarray, xr.DataArray]:
+    """Compute 'actual' saturation vapor pressure [kPa] as described in the
+    Food and Agriculture Organization (FAO) Irrigation and Drainage Paper 56
+    entitled:
+
+    Crop evapotranspiration - Guidelines for computing crop water
+    requirement. Specifically, see equation 14 of Chapter 3.
+
+    The dew point temperature is synonymous with the wet bulb temperature.
+
+    Note that this function is the same as saturation_vapor_pressure, but with
+    temperature = dew point temperature with different metadata
+
+    Parameters
+    ----------
+    tdew : ndarray, :class:`xarray.DataArray`, :class:`list`, :class:`float`
+        Dew point temperatures in Fahrenheit
+
+    tfill : float, numpy.nan, optional
+        An optional parameter for a fill value in the return value
+
+    Returns
+    -------
+    asvp : ndarray, :class:`xarray.DataArray`
+        the computed actual saturation vapor pressure in kPa.
+        Same shape as tdew.
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> from geocat.comp import actual_saturation_vapor_pressure
+    >>> temp = np.array([50, 60, 70])
+    >>> actual_saturation_vapor_pressure(temp)
+    array([1.22796262, 1.76730647, 2.50402976])
+
+
+    See Also
+    --------
+    Related GeoCAT Functions:
+    `saturation_vapor_pressure <https://geocat-comp.readthedocs.io/en/latest/user_api/generated/geocat.comp.crop.saturation_vapor_pressure.html#geocat.comp.crop.saturation_vapor_pressure>`__,
+    `saturation_vapor_pressure_slope <https://geocat-comp.readthedocs.io/en/latest/user_api/generated/geocat.comp.crop.saturation_vapor_pressure_slope.html#geocat.comp.crop.saturation_vapor_pressure_slope>`__
+
+    Related NCL Functions:
+    `satvpr_tdew_fao56 <https://www.ncl.ucar.edu/Document/Functions/Crop/satvpr_tdew_fao56.shtml>`__
+    """
+
+    in_type = type(tdew)
+
+    asvp = saturation_vapor_pressure(tdew, tfill)
+
+    # reformat metadata for xarray
+    if in_type is xr.DataArray:
+        asvp.attrs['long_name'] = "actual saturation vapor pressure via Tdew"
+        asvp.attrs['units'] = "kPa"
+        asvp.attrs['url'] = "https://www.fao.org/docrep/X0490E/x0490e07.htm"
+        asvp.attrs['info'] = "FAO 56; EQN 14; actual_saturation_vapor_pressure"
+
+    return asvp
+
+
+def saturation_vapor_pressure_slope(
+    temperature: typing.Union[np.ndarray, xr.DataArray, list, float],
+    tfill: typing.Union[float] = np.nan
+) -> typing.Union[np.ndarray, xr.DataArray]:
+    """Compute the slope [kPa/C] of saturation vapor pressure curve as
+    described in the Food and Agriculture Organization (FAO) Irrigation and
+    Drainage Paper 56 entitled:
+
+    Crop evapotranspiration - Guidelines for computing crop water
+    requirement. Specifically, see equation 13 of Chapter 3.
+
+    Parameters
+    ----------
+    temperature : ndarray, :class:`xarray.DataArray`, :class:`list`, :class:`float`
+        Temperature in Fahrenheit
+
+    tfill : float, numpy.nan, optional
+        An optional parameter for a fill value in the return value
+
+    Returns
+    -------
+    svp_slope : ndarray, :class:`xarray.DataArray`
+        The computed slopes of the saturation vapor pressure curve.
+        Will be the same shape as temperature.
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> from geocat.comp import saturation_vapor_pressure_slope
+    >>> temp = np.array([50, 60, 70])
+    >>> saturation_vapor_pressure_slope(temp)
+    array([0.08224261, 0.11322096, 0.153595  ])
+
+
+    See Also
+    --------
+    Related GeoCAT Functions:
+    `actual_saturation_vapor_pressure <https://geocat-comp.readthedocs.io/en/latest/user_api/generated/geocat.comp.crop.actual_saturation_vapor_pressure.html#geocat.comp.crop.actual_saturation_vapor_pressure>`__,
+    `saturation_vapor_pressure_slope <https://geocat-comp.readthedocs.io/en/latest/user_api/generated/geocat.comp.crop.saturation_vapor_pressure_slope.html#geocat.comp.crop.saturation_vapor_pressure_slope>`__
+
+    Related NCL Functions:
+    `satvpr_temp_fao56 <https://www.ncl.ucar.edu/Document/Functions/Crop/satvpr_temp_fao56.shtml>`__
+    """
+    in_type = type(temperature)
+
+    if in_type is xr.DataArray:
+
+        # convert to Celsius
+        temp_c = (temperature - 32) * 5 / 9
+
+        # calculate svp_slope
+        svp_slope = xr.where(
+            temp_c > 0, 4096 * (0.6108 * np.exp(
+                (17.27 * temp_c) / (temp_c + 237.3)) / (temp_c + 237.3)**2),
+            tfill)
+
+        # add relevant metadata
+        svp_slope.attrs['long_name'] = "slope saturation vapor pressure curve"
+        svp_slope.attrs['units'] = "kPa/C"
+        svp_slope.attrs[
+            'url'] = "https://www.fao.org/docrep/X0490E/x0490e07.htm"
+        svp_slope.attrs[
+            'info'] = "FAO 56; EQN 13; saturation_vapor_pressure_slope"
+
+    else:
+        temperature = np.asarray(temperature)
+
+        # convert to Celsius
+        temp_c = (temperature - 32) * 5 / 9
+
+        # calculate svp_slope
+        svp_slope = np.where(
+            temp_c > 0, 4096 * (0.6108 * np.exp(
+                (17.27 * temp_c) / (temp_c + 237.3)) / (temp_c + 237.3)**2),
+            tfill)
+
+    return svp_slope
